@@ -19,7 +19,6 @@
 	*************************************************************************
 */
 
-
 #ifndef LIBOSCAR_CLIENT_H
 #define LIBOSCAR_CLIENT_H
 
@@ -27,7 +26,8 @@
 #include <qstring.h>
 #include <QList>
 #include <QByteArray>
-#include "kopete_export.h"
+#include <KLocalizedString>
+#include "oscar_export.h"
 #include "rtf2html.h"
 #include "transfer.h"
 #include "icquserinfo.h"
@@ -49,7 +49,6 @@ class ChatRoomHandler;
 namespace Kopete
 {
 	class Transfer;
-	class TransferManager;
 }
 
 namespace Oscar
@@ -404,7 +403,7 @@ public:
 	 */
 	FileTransferHandler* createFileTransfer( const QString& contact, const QStringList& files );
 
-	void inviteToChatRoom( const QString& contact, Oscar::WORD exchange, const QString& room, QString msg="Join me in this Chat." );
+    void inviteToChatRoom( const QString& contact, Oscar::WORD exchange, const QString& room, QString msg= i18n("Join me in this Chat.") );
 
 	/*************
 	  INTERNAL (FOR USE BY TASKS OR CONNECTIONS) METHODS
@@ -460,10 +459,10 @@ public:
 	/** Notify that a socket error has occurred */
 	void notifySocketError( int errCode, const QString& msg );
 
-public slots:
+public Q_SLOTS:
 	void joinChatRoom( const QString& roomName, int exchange );
 
-signals:
+Q_SIGNALS:
 	/** CONNECTION EVENTS */
 
 	/** Notifies that we want to create new stream.
@@ -563,7 +562,7 @@ signals:
 	/** incoming filetransfer */
 	void incomingFileTransfer( FileTransferHandler* handler );
 
-protected slots:
+protected Q_SLOTS:
 	// INTERNAL, FOR USE BY TASKS' finished() SIGNALS //
 
 	/** Singleshot timer to start stage two login */
@@ -657,6 +656,3 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Oscar::Client::ICQStatus)
 
 #endif
 
-//kate: tab-width 4; indent-mode csands;
-
-
